debugpy: An implementation of the Debug Adapter Protocol for Python
===================================================================

Description
-----------

An implementation of the Debug Adapter Protocol for Python

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/debugpy/

